function y = BinomialTree(Spot,Strike,r,v,T,n,PutCall,EuroAmer)

dt = T/n;
u = exp(v*sqrt(dt));
d = 1/u;
p = (exp(r*dt)-d)/(u-d);
exp_rT = exp(-r*dt);

S = zeros(n+1,n+1);
V = zeros(n+1,n+1);

% Asset Price Dynamics
for i = 1:n+1
    for j = i:n+1
         S(i,j) = Spot*u^(j-i)*d^(i-1);
	end
end

% Terminal option Prices
for i = 1:n+1
    switch PutCall
        case 'C'
            V(i,n+1) = max(S(i,n+1) - Strike,0);
        case 'P'
            V(i,n+1) = max(Strike - S(i,n+1),0);
	end
end

% Remaining Asset Prices
for j = n:-1:1
    for i = 1:j
    switch EuroAmer
        case 'E'
            V(i,j) = exp_rT*(p*V(i,j+1) + (1-p)*V(i+1,j+1));
		case 'A'
            if strcmp(PutCall, 'C')
                V(i,j) = max(S(i,j)-Strike, exp_rT*(p*V(i,j+1) + (1-p)*V(i+1,j+1)));
			else
                V(i,j) = max(Strike-S(i,j), exp_rT*(p*V(i,j+1) + (1-p)*V(i+1,j+1)));
			end
	end
	end
end

y = V(1,1);
