% Single barrier options using a binomial tree.
% Optimal number of steps using the method of Boyle and Lau (1994).
% Barrier adjustment for continuous or discrete monitoring.

clc; clear;

S = 100;          % Spot price.
K = 105;          % Strike price.
H = 110;          % Barrier level.
T = 1;            % Maturity.
r = 0.1;          % Risk free rate
v = 0.25;         % Volatility.
n = 150;          % Number of steps.
PutCall = 'C';    % 'C'all or 'P'ut
EuroAmer = 'A';   % 'E'uropean or 'A'merican
BarType = 'UO';   % 'DO', 'DI', 'UO', 'UI'
M1 = 0;           % Barrier monitor for # observations
M2 = 'W';         % Barrier monitor for frequency 'C'ontinuous 'H'ourly, 'D'aily, 'W'eekly, 'M'onthly.

% Returns the optimal number of time steps and the option price.
[OptimalN BarrierOptionPrice] = BoyleLauBarrierTree(S,K,H,T,r,v,n,PutCall,EuroAmer,BarType,M1,M2)

% Returns the barrier modified for monitoring frequency.
ModifiedBarrier = NewBarrier(S,H,T,v,M1,M2)
